@@ -15,6 +15,7 @@ from .generic import (
     EncodedStreamObject,
     IndirectObject,
     NullObject,
+    TextStringObject,
 )
 
 if sys.version_info[:2] >= (3, 10):
@@ -45,14 +46,14 @@ def _get_imagemode(
     depth: int = 0,
 ) -> Tuple[mode_str_type, bool]:
     """
-    Returns
-        Image mode not taking into account mask(transparency)
-        ColorInversion is required (like for some DeviceCMYK)
+    Returns:
+        Image mode, not taking into account mask (transparency).
+        ColorInversion is required (like for some DeviceCMYK).
 
     """
     if depth > MAX_IMAGE_MODE_NESTING_DEPTH:
         raise PdfReadError(
-            "Color spaces nested too deep. If required, consider increasing MAX_IMAGE_MODE_NESTING_DEPTH."
+            "Color spaces nested too deeply. If required, consider increasing MAX_IMAGE_MODE_NESTING_DEPTH."
         )
     if isinstance(color_space, NullObject):
         return "", False
@@ -60,7 +61,7 @@ def _get_imagemode(
         pass
     elif not isinstance(color_space, list):
         raise PdfReadError(
-            "Cannot interpret colorspace", color_space
+            "Cannot interpret color space", color_space
         )  # pragma: no cover
     elif color_space[0].startswith("/Cal"):  # /CalRGB and /CalGray
         color_space = "/Device" + color_space[0][4:]
@@ -152,7 +153,7 @@ def _extended_image_frombytes(
         if data_length % nb_pix != 0:
             raise exc
         k = nb_pix * len(mode) / data_length
-        data = b"".join([bytes((x,) * int(k)) for x in data])
+        data = b"".join(bytes((x,) * int(k)) for x in data)
         img = Image.frombytes(mode, size, data)
     return img
 
@@ -184,8 +185,6 @@ def _handle_flate(
         data = bits2byte(data, size, 4)
     img = _extended_image_frombytes(mode, size, data)
     if color_space == "/Indexed":
-        from .generic import TextStringObject
-
         if isinstance(lookup, (EncodedStreamObject, DecodedStreamObject)):
             lookup = lookup.get_data()
         if isinstance(lookup, TextStringObject):
@@ -226,15 +225,11 @@ def _handle_flate(
                     lookup = lookup[:expected_count]
                 colors_arr = [lookup[:nb], lookup[nb:]]
                 arr = b"".join(
-                    [
-                        b"".join(
-                            [
-                                colors_arr[1 if img.getpixel((x, y)) > 127 else 0]
-                                for x in range(img.size[0])
-                            ]
-                        )
-                        for y in range(img.size[1])
-                    ]
+                    b"".join(
+                        colors_arr[1 if img.getpixel((x, y)) > 127 else 0]
+                        for x in range(img.size[0])
+                    )
+                    for y in range(img.size[1])
                 )
                 img = Image.frombytes(mode, img.size, arr)
             else:
@@ -295,7 +290,7 @@ def _handle_jpx(
         mode = "RGBA"
     # we need to convert to the good mode
     if img1.mode == mode or {img1.mode, mode} == {"L", "P"}:  # compare (unordered) sets
-        # L,P are indexed modes which should not be changed.
+        # L and P are indexed modes which should not be changed.
         img = img1
     elif {img1.mode, mode} == {"RGBA", "CMYK"}:
         # RGBA / CMYK are 4bytes encoding where
@@ -319,7 +314,7 @@ def _apply_decode(
     color_space: Union[str, List[Any], Any],
     invert_color: bool,
 ) -> Image.Image:
-    # CMYK image and other colorspaces without decode
+    # CMYK image and other color spaces without decode
     # requires reverting scale (cf p243,2§ last sentence)
     decode = x_object_obj.get(
         IA.DECODE,
@@ -334,7 +329,7 @@ def _apply_decode(
         isinstance(color_space, ArrayObject)
         and color_space[0].get_object() == "/Indexed"
     ):
-        decode = None  # decode is meanless of Indexed
+        decode = None  # decode is meaningless if Indexed
     if (
         isinstance(color_space, ArrayObject)
         and color_space[0].get_object() == "/Separation"
